"""
commandline.py

Fancy command-line functions, classes, etc.

:author:        Stephen Stauts
:created:       07/03/2020   (DD/MM/YYYY)
:copyright:     © 2020 Stephen Stauts. All Rights Reserved.
"""

# Standard Packages
import sys

# Dependency Packages
try:
    import docopt       # Not a hard requirement; functions disabled otherwise
except ImportError:
    DOCOPT_EXISTS = False
else:
    DOCOPT_EXISTS = True

# Local Packages and Modules


def get_docopt_args(docs, **kwargs):
    """
    Return a dictionary of Docopt arguments parsed from the commandline. These
    arguments can be returend as-is, or cleaned up to better represent normal
    python keyword arguments that follow the PEP8 format.

    :param str docs:    Docstring used by docopt for parsing arguments, usually
                        the main file module docstring.
    :kwarg bool clean:  Clean up the arguments to remove argument characters.
                        This is recommended if the arguments are passed in
                        as keyword arguments to other functions so that they
                        match the standard PEP8 format of arguments.
    """
    if not DOCOPT_EXISTS:
        raise ImportError('The docopt package is not installed.')

    clean = kwargs.get('clean', True)

    try:
        d_args = docopt.docopt(docs)
    except docopt.DocoptExit:
        print('ERROR: Command line contained one or more invalid arguments.')
        print(docs)
        sys.exit(1)

    if clean:
        d_clean_args = dict()
        for key, value in d_args.items():
            clean_key = key.lstrip('--')
            clean_key = clean_key.replace('-', '_').replace('<', '').replace('>', '')
            d_clean_args[clean_key] = value
        return d_clean_args

    return d_args
